failUnder property

double? failUnder
final

Minimum coverage threshold percentage.

If specified and the total coverage falls below this threshold, the program will exit with code 1. Useful for CI/CD pipelines.

Must be between 0.0 and 100.0.

Implementation

final double? failUnder;