outputPath property
Path to save the output report.
If null, the report will be printed to stdout.
Implementation
final String? outputPath;
Path to save the output report.
If null, the report will be printed to stdout.
final String? outputPath;