summary property
Whether to output summary with individual file coverage.
When true, shows individual file coverage percentages and total
instead of the full detailed report.
Implementation
final bool summary;
Whether to output summary with individual file coverage.
When true, shows individual file coverage percentages and total
instead of the full detailed report.
final bool summary;