issueTracker constant

String const issueTracker

Issue tracker

Current app issueTracker

The optional issue_tracker field should contain a URL for the package’s issue tracker, where existing bugs can be viewed and new bugs can be filed. The pub.dev site attempts to display a link to each package’s issue tracker, using the value of this field. If issue_tracker is missing but repository is present and points to GitHub, then the pub.dev site uses the default issue tracker https://github.com/user/repository/issues

Implementation

static const String issueTracker = r'https://github.com/Jei-sKappa/buggy/issues';