ReportConfig class
Configuration class for the Buggy.
Defines all the settings and options for generating coverage reports.
Example:
final config = ReportConfig(
inputPath: 'coverage/lcov.info',
outputPath: 'coverage_report.md',
excludePatterns: ['**/test/**', '*.g.dart'],
uncoveredOnly: true,
failUnder: 80.0,
summary: false,
noFilter: false,
);
Constructors
Properties
-
excludeLinePatterns
→ List<
String> -
Specific lines to exclude from coverage calculations.
final
-
excludePatterns
→ List<
String> -
Glob patterns to exclude files from the report.
final
- failUnder → double?
-
Minimum coverage threshold percentage.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputPath → String
-
Path to the input LCOV file.
final
- noFilter → bool
-
Whether to disable filtering of common useless lines.
final
- outputPath → String?
-
Path to save the output report.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → bool
-
Whether to output summary with individual file coverage.
final
- uncoveredOnly → bool
-
Whether to show only files with uncovered lines.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited