utils/config_file library
Functions
-
findPreset(
YamlMap config, List< String> commandPath, String presetName) → Map<String, dynamic> -
Looks up a preset by
presetNamefor the givencommandPath. -
loadConfigFile(
) → YamlMap? - Attempts to load a buggy config file from the current directory.
-
presetToArguments(
Map< String, dynamic> preset) → List<String> - Converts a preset map into a list of CLI-style arguments.